@@ -733,8 +733,8 @@ void QsciScintilla::startAutoCompletion(AutoCompletionSource acs,
     SendScintilla(SCI_AUTOCSETCHOOSESINGLE, single);
     SendScintilla(SCI_AUTOCSETSEPARATOR, acSeparator);
 
-    QString chlist = wlist.join(QChar(acSeparator));
-    SendScintilla(SCI_AUTOCSHOW, last_len, chlist.latin1());
+    ScintillaString wlist_s = convertTextQ2S(wlist.join(QChar(acSeparator)));
+    SendScintilla(SCI_AUTOCSHOW, last_len, ScintillaStringData(wlist_s));
 }
 
 
@@ -3356,8 +3356,9 @@ void QsciScintilla::showUserList(int id, const QStringList &list)
         return;
 
     SendScintilla(SCI_AUTOCSETSEPARATOR, userSeparator);
-    SendScintilla(SCI_USERLISTSHOW, id,
-            list.join(QChar(userSeparator)).latin1());
+
+    ScintillaString s = convertTextQ2S(list.join(QChar(userSeparator)));
+    SendScintilla(SCI_USERLISTSHOW, id, ScintillaStringData(s));
 }
 
 
@@ -3502,7 +3503,7 @@ void QsciScintilla::setAnnotationDisplay(QsciScintilla::AnnotationDisplay displa
 // Clear annotations.
 void QsciScintilla::clearAnnotations(int line)
 {
-    if (line < 0)
+    if (line >= 0)
         SendScintilla(SCI_ANNOTATIONSETTEXT, line, (const char *)0);
     else
         SendScintilla(SCI_ANNOTATIONCLEARALL);
